;
; Sample program for BFFCOMMS usage - Case 1 Simple serial write and read
;
;
; Ian Hopper - BFF Design Ltd - June 2010
; Ian@builtforfun.co.uk - http://builtforfun.co.uk/
; 
;======================================================================================
; This file is part of BFF Serial Comms for PICAXE.
;
;    BFF Serial Comms for PICAXE is free software; you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation; either version 3 of the License, or
;    (at your option) any later version.
;
;    BFF Serial Comms for PICAXE is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU General Public License for more details.
;
;    You should have received a copy of the GNU General Public License
;    along with this program.  If not, see http://www.gnu.org/licenses/.
;
;======================================================================================
;

#NoEnv  ; Recommended for performance and compatibility with future AutoHotkey releases.
SendMode Input  ; Recommended for new scripts due to its superior speed and reliability.
SetWorkingDir %A_ScriptDir%  ; Ensures a consistent starting directory.
SetBatchLines -1
Process Priority,,Normal
SetKeyDelay -1

; Bring in the external scripts with the functions
#Include BFFCOMMS_Func.ahk
; Use fast floats
SetFormat, FloatFast, 0.8
; Delete the log file
FileDelete, BFF_Comms.log
; Tray Icon?
Menu, Tray,  Icon, favicon.ico, 1



;================================================================
;The main procedure
;================================================================

; open the com port and set the baud to 115200, read timeout to 500ms, allow abort errors

COMPort := "COM1"
Baud := 115200
Timeout := 500    ;ms

iret := BFFCOMMS_Open(COMPort, Baud, Handle, Timeout, 0)
if (iret != 0)
  MsgBox, Error reported by BFFCOMMS_Open: %iret%
else
  MsgBox, BFFCOMMS_Open: com port opened, Handle: %Handle% `n`nReady to write...  

  
; send the bytes A, B, 50, 100, 150

dFormat := "AABBB"   ;5 bytes long, 1st two are sent as Ascii characters, remaining three bytes are sent as binary numbers
b1 := "A"
b2 := "B"
b3 := 50
b4 := 100
b5 := 150

iret := BFFCOMMS_Send(Handle, dFormat, b1, b2, b3, b4, b5) 
if (iret != 0)
  MsgBox, Error reported by BFFCOMMS_Send: %iret%
else
  MsgBox, BFFCOMMS_Send: data sent: %b1%, %b2%, %b3%, %b4%, %b5% `n`nReady to read....
  
  
; now pause a moment (100ms)

DllCall("Sleep", UInt, 100)


; read the echo from the PICAXE chip - same format, so AABBB = read two ascii bytes then three binary bytes

dFormat := "AABBB"
b1 := 0
b2 := 0
b3 := 0
b4 := 0
b5 := 0

iret := BFFCOMMS_Get(Handle, dFormat, b1, b2, b3, b4, b5)
if (iret = -1)
  MsgBox, Read timeout reported by BFFCOMMS_Get: %iret%
else if (iret != 0)
  MsgBox, Error reported by BFFCOMMS_Get: %iret%
else
  MsgBox, BFFCOMMS_Get: data returned: %b1%, %b2%, %b3%, %b4%, %b5% `n`nClosing port....
  
  
; Close the comport

iret := BFFCOMMS_Close(Handle)
if (iret != 0)
  MsgBox, Error reported by BFFCOMMS_Close: %iret%


; And close the application

ExitApp


















