;
; Sample program for BFFCOMMS usage - Case 2 Simple serial write and read with Ascii qualifiers
;
; Note that if you specify a serial read with qualifers (ie an ascii string to listen out for before
; reading remaining data) then the program will wait indefinately for that qualifier string to appear.
; Use the BFFCOMMS_QTO constant to switch the timeout on, ie BFFCOMMS_QTO := 1
;
; Ian Hopper - BFF Design Ltd - June 2010
; Ian@builtforfun.co.uk - http://builtforfun.co.uk/
; 
;======================================================================================
; This file is part of BFF Serial Comms for PICAXE.
;
;    BFF Serial Comms for PICAXE is free software; you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation; either version 3 of the License, or
;    (at your option) any later version.
;
;    BFF Serial Comms for PICAXE is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU General Public License for more details.
;
;    You should have received a copy of the GNU General Public License
;    along with this program.  If not, see <http://www.gnu.org/licenses/>.
;
;======================================================================================
;

#NoEnv  ; Recommended for performance and compatibility with future AutoHotkey releases.
SendMode Input  ; Recommended for new scripts due to its superior speed and reliability.
SetWorkingDir %A_ScriptDir%  ; Ensures a consistent starting directory.
SetBatchLines -1
Process Priority,,Normal
SetKeyDelay -1

; Bring in the external scripts with the functions
#Include BFFCOMMS_Func.ahk
; Use fast floats
SetFormat, FloatFast, 0.8
; Delete the log file
FileDelete, BFF_Comms.log
; Tray Icon?
Menu, Tray,  Icon, favicon.ico, 1



;================================================================
;The main procedure
;================================================================

; open the com port and set the baud to 115200, read timeout to 500ms

COMPort := "COM1"
Baud := 115200
Timeout := 500    ;ms

iret := BFFCOMMS_Open(COMPort, Baud, Handle, Timeout, 0)
if (iret != 0)
  MsgBox, Error reported by BFFCOMMS_Open: %iret%
else
  MsgBox, BFFCOMMS_Open: com port opened, Handle: %Handle% `n`nReady to write...     

  
; send the bytes A, B, 50, 100, 150

dFormat := "AABBB"   ;set the data format - 5 bytes long, 1st two are sent as Ascii characters, remaining three bytes are sent as binary numbers
b1 := "A"
b2 := "B"
b3 := 50
b4 := 100
b5 := 150

iret := BFFCOMMS_Send(Handle, dFormat, b1, b2, b3, b4, b5) 
if (iret != 0)
  MsgBox, Error reported by BFFCOMMS_Send: %iret%
else
  MsgBox, BFFCOMMS_Send: data sent: %b1%, %b2%, %b3%, %b4%, %b5% `n`nReady to read....
  
  
; now pause a moment (100ms)

DllCall("Sleep", UInt, 100)


; Switch the timeout on wait for qualifiers ON

BFFCOMMS_QTO := 1


; and read the response from the PICAXE chip - listen for string "CD" then read further 5 bytes - note function will wait indefinately for the qualifiers
; and the program may appear to hang if BFFCOMMS_QTO = 0 and the qualifiers never appear in the serial data stream...

dFormat := "QQBBBBB"      ;data format - 7 bytes, 1st two are the ascii qualifiers, rest indicate 5 binary bytes
b6 := "C"
b7 := "D"

iret := BFFCOMMS_Get(Handle, dFormat, b6, b7, b8, b9, b10, b11, b12)    ;b6 and 7 are the qualifiers, b8-12 are the received data following the qualifiers
if (iret = -1)
  MsgBox, Read timeout reported by BFFCOMMS_Get: %iret%
else if (iret != 0)
  MsgBox, Error reported by BFFCOMMS_Get: %iret%
else
  MsgBox, BFFCOMMS_Get: data returned: %b6%, %b7%, %b8%, %b9%, %b10%, %b11%, %b12% `n`nClosing port....
  
  
; Close the comport

iret := BFFCOMMS_Close(Handle)
if (iret != 0)
  MsgBox, Error reported by BFFCOMMS_Close: %iret%


; And close this application

ExitApp


















