;
; Sample program for BFFCOMMS usage - Case 3 Send keystrokes to flash LED's
;
; This program includes a simple GUI window and threads for button clicks and keystroke actions
;
; Ian Hopper - BFF Design Ltd - June 2010
; Ian@builtforfun.co.uk - http://builtforfun.co.uk/
; 
;======================================================================================
; This file is part of BFF Serial Comms for PICAXE.
;
;    BFF Serial Comms for PICAXE is free software; you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation; either version 3 of the License, or
;    (at your option) any later version.
;
;    BFF Serial Comms for PICAXE is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU General Public License for more details.
;
;    You should have received a copy of the GNU General Public License
;    along with this program.  If not, see <http://www.gnu.org/licenses/>.
;
;======================================================================================
;

#NoEnv  ; Recommended for performance and compatibility with future AutoHotkey releases.
SendMode Input  ; Recommended for new scripts due to its superior speed and reliability.
SetWorkingDir %A_ScriptDir%  ; Ensures a consistent starting directory.
SetBatchLines -1
Process Priority,,Normal
SetKeyDelay -1

; Bring in the external scripts with the functions
#Include BFFCOMMS_Func.ahk
; Use fast floats
SetFormat, FloatFast, 0.8
; Delete the log file
FileDelete, BFF_Comms.log
; Tray Icon?
Menu, Tray,  Icon, favicon.ico, 1



;================================================================
;Simple GUI Window
;================================================================

Gui, Color, Silver
Gui, Add, GroupBox, x5 y5 w138 h109 , BFFCOMMS Case 3
Gui, Add, Text, x21 y29 w100 h30 +center vText1, Text
Gui, Add, Button, x21 y72 w100 h30 , Close
Gui, Show, x50 y50 h122 w150, BFFCOMMS Case 3

;================================================================
;Go straight to opening the COM port
;================================================================

; open the com port and set the baud to 115200, read timeout to 500ms

COMPort := "COM1"
Baud := 115200
Timeout := 500    ;ms

iret := BFFCOMMS_Open(COMPort, Baud, Handle, Timeout, 0)
if (iret != 0)
  MsgBox, Error reported by BFFCOMMS_Open: %iret%
else
  GuiControl,, Text1, Port:%COMPort% `nBaud:%Baud%   
  
;set the timeout on wait for qualifiers to ON
; = 0 for off, this applies to any calls to BFFCOMMS_Get() which include ascii qualifiers in the serial data

BFFCOMMS_QTO = 1

; End of initialisation thread

Return  



;================================================================
;Thread to execute when Close button is clicked....
;================================================================

ButtonClose:
  Goto Finish
Return



;================================================================
;Threads to execute on selected keypresses
;================================================================

g::
  KeyStroke := "G"
  Goto Write
Return


a::
  KeyStroke := "A"
  Goto Write
Return

r::
  KeyStroke := "R"
  Goto Write
Return





; Code for serial write and read - threads come here if "goto Write" is used

Write:

; send the bytes "X" and Keystroke, Keystroke is set by the calling code 

dFormat := "AA"   ;set the data format - 2 bytes long, both sent as Ascii characters
b1 := "X"

iret := BFFCOMMS_Send(Handle, dFormat, b1, Keystroke) 
if (iret != 0)
  MsgBox, Error reported by BFFCOMMS_Send: %iret%
else
  GuiControl,, Text1, Sent %Keystroke% `nwaiting...

; now pause a moment (100ms)

DllCall("Sleep", UInt, 100)


; and read the response from the PICAXE chip - listen for string "CD" then read further 1 byte

dFormat := "QQA"      ;data format - 3 bytes - 2 qualifier chars and one ascii byte
b1 := "C"
b2 := "D"
b3 := 0

iret := BFFCOMMS_Get(Handle, dFormat, b1, b2, b3)
if (iret = -1)
  GuiControl,, Text1, Sent %Keystroke%`nTimed-out..
else if (iret != 0)
  MsgBox, Error reported by BFFCOMMS_Get: %iret%
else
  GuiControl,, Text1, Sent %Keystroke%`nGot back %b1%%b2% %b3%
  
; return the thread
  
Return
  


  
; Code to Close the comport

Finish:

iret := BFFCOMMS_Close(Handle)
if (iret != 0)
  MsgBox, Error reported by BFFCOMMS_Close: %iret%


; And close this application

ExitApp







