;
; Sample program for BFFCOMMS usage - Case 4 Read joystick axis positions and send to PICAXE
;
;
; Ian Hopper - BFF Design Ltd - June 2010
; Ian@builtforfun.co.uk - http://builtforfun.co.uk/
; 
;======================================================================================
; This file is part of BFF Serial Comms for PICAXE.
;
;    BFF Serial Comms for PICAXE is free software; you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation; either version 3 of the License, or
;    (at your option) any later version.
;
;    BFF Serial Comms for PICAXE is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU General Public License for more details.
;
;    You should have received a copy of the GNU General Public License
;    along with this program.  If not, see <http://www.gnu.org/licenses/>.
;
;======================================================================================
;

#NoEnv  ; Recommended for performance and compatibility with future AutoHotkey releases.
SendMode Input  ; Recommended for new scripts due to its superior speed and reliability.
SetWorkingDir %A_ScriptDir%  ; Ensures a consistent starting directory.
SetBatchLines -1    ;Maximise script processing speed
Process Priority,,Normal
SetKeyDelay -1

; Bring in the external scripts with the functions
#Include BFFCOMMS_Func.ahk
; Use fast floats
SetFormat, FloatFast, 0.8
; Delete the log file
FileDelete, BFF_Comms.log
; Tray Icon?
Menu, Tray,  Icon, favicon.ico, 1



;================================================================
;Simple GUI Window
;================================================================

Gui, Color, Silver
Gui, Add, GroupBox, x153 y181 w76 h34 , GroupBox
Gui, Add, GroupBox, x6 y5 w171 h113 , BFFCOMMS Case 4
Gui, Add, Edit, x14 y22 w154 h50 -VScroll +center vText1, Text
Gui, Add, Button, x41 y79 w100 h30 , Close
Gui, Show, x50 y50 h126 w185, BFFCOMMS Case 4


;Go straight to opening the COM port

COMPort := "COM1"
Baud := 115200
Timeout := 500    ;ms

iret := BFFCOMMS_Open(COMPort, Baud, Handle, Timeout, 0)
if (iret != 0)
  {
  MsgBox, Error reported by BFFCOMMS_Open: %iret%
  Goto Finish
  }
else
  GuiControl,, Text1, Port:%COMPort% `nBaud:%Baud%   

Sleep, 1000


;Set up the timer

DllCall("QueryPerformanceFrequency", "Int64*", T_Cal)   ;system clock ticks per second
DllCall("QueryPerformanceCounter", "Int64*", T_Prev)    ;current time in ticks



; Main program loop to read stick positions and send to PICAXE

MainLoop:

; Pause for 20 ms so as not to consume CPU share

DllCall("Sleep", UInt, 20)


;Calculate the loop frequncy to display in the window

DllCall("QueryPerformanceCounter", "Int64*", T_Now)
T_Loop := (T_Now - T_Prev) / T_Cal
F_Loop := Round(1 / T_Loop, 1)
T_Prev := T_Now


; Read the joystick axis positions (values affected by Windows stick calibration)

GetKeyState, joyx_val, 1JoyX    ;in range 0-50-100
GetKeyState, joyy_val, 1JoyY
GetKeyState, joyz_val, 1JoyZ
  
joyx_val := Round(joyx_val * 2.55, 0)    ;now position is an integer in range 0 to 255
joyy_val := Round(joyy_val * 2.55, 0)
joyz_val := Round(joyz_val * 2.55, 0)

  
; send the positions to the chip

dFormat := "AABBB"   ;set the data format - 5 bytes long, 1st two are sent as ascii characters, remaining three as raw data bytes
b1 := "X"
b2 := "X"            ;these format settings could be made outside the loop because they don't change

iret := BFFCOMMS_Send(Handle, dFormat, b1, b2, joyx_val, joyy_val, joyz_val) 
if (iret != 0)
  {
  MsgBox, Error reported by BFFCOMMS_Send: %iret%
  Goto Finish
  }
else
  GuiControl,, Text1, Sending %joyx_val% `n%joyy_val% & %joyz_val%`n at %F_Loop% Hz
  
  
; now go back and loop again - ie thread is never ending

Goto MainLoop




Finish:  
  
; Close the comport

iret := BFFCOMMS_Close(Handle)
if (iret != 0)
  MsgBox, Error reported by BFFCOMMS_Close: %iret%

; And close this application

ExitApp




;================================================================
;Thread to execute when Close button is clicked....
;================================================================

ButtonClose:
  Goto Finish
Return











