;
; Sample program for BFFCOMMS usage - Case 5 Monitor ADC readings from PICAXE
;
;
; Ian Hopper - BFF Design Ltd - June 2010
; Ian@builtforfun.co.uk - http://builtforfun.co.uk/
; 
;======================================================================================
; This file is part of BFF Serial Comms for PICAXE.
;
;    BFF Serial Comms for PICAXE is free software; you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation; either version 3 of the License, or
;    (at your option) any later version.
;
;    BFF Serial Comms for PICAXE is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU General Public License for more details.
;
;    You should have received a copy of the GNU General Public License
;    along with this program.  If not, see <http://www.gnu.org/licenses/>.
;
;======================================================================================
;

#NoEnv  ; Recommended for performance and compatibility with future AutoHotkey releases.
SendMode Input  ; Recommended for new scripts due to its superior speed and reliability.
SetWorkingDir %A_ScriptDir%  ; Ensures a consistent starting directory.
SetBatchLines -1    ;Maximise script processing speed
Process Priority,,Normal
SetKeyDelay -1

; Bring in the external scripts with the functions
#Include BFFCOMMS_Func.ahk
; Use fast floats
SetFormat, FloatFast, 0.8
; Delete the log file
FileDelete, BFF_Comms.log
; Tray Icon?
Menu, Tray,  Icon, favicon.ico, 1



;================================================================
;Simple GUI Window
;================================================================

Gui, Color, Silver
Gui, Add, GroupBox, x153 y181 w76 h34 , GroupBox
Gui, Add, GroupBox, x6 y5 w171 h113 , BFFCOMMS Case 5
Gui, Add, Edit, x14 y22 w154 h50 -VScroll +center vText1, Text
Gui, Add, Button, x41 y79 w100 h30 , Close
Gui, Show, x50 y50 h126 w185, BFFCOMMS Case 5


;Go straight to opening the COM port

COMPort := "COM1"
Baud := 115200
Timeout := 500    ;ms

iret := BFFCOMMS_Open(COMPort, Baud, Handle, Timeout, 1)      ;disable AbortOnError as fast data reads might throw up windows 995 errors
if (iret != 0)
  {
  MsgBox, Error reported by BFFCOMMS_Open: %iret%
  Goto Finish
  }
else
  GuiControl,, Text1, Port:%COMPort% `nBaud:%Baud%   

Sleep, 1000


;Set up the timer

DllCall("QueryPerformanceFrequency", "Int64*", T_Cal)   ;system clock ticks per second
DllCall("QueryPerformanceCounter", "Int64*", T_Prev)    ;current time in ticks


;Switch timeout on serial data qualifier reads to ON

BFFCOMMS_QTO := 1


; Main program loop to read stick positions and send to PICAXE

Loop
{

; Pause for 10 ms so as not to consume CPU share

DllCall("Sleep", UInt, 10)


;Calculate the loop frequency to display in the window

DllCall("QueryPerformanceCounter", "Int64*", T_Now)
T_Loop := (T_Now - T_Prev) / T_Cal
F_Loop := Round(1 / T_Loop, 1)
T_Prev := T_Now


;Purge the read buffer to get freshest data

iret := BFFCOMMS_Purge(Handle)
if (iret != 0)
  MsgBox, Error reported by BFFCOMMS_Purge: %iret%
  
  
; read the ADC data from the chip - 3 word variables

dFormat := "QQBBBBBB"   ;set the data format, 2 qualifer bytes and 6 data bytes
b1 := "C"
b2 := "D"            ;these format settings could be made outside the loop because they don't change

Timeout_flag := "No"

iret := BFFCOMMS_Get(Handle, dFormat, b1, b2, b3, b4, b5, b6, b7, b8)
if (iret = -1)
  Timeout_flag := "Yes"       ;NOTE if timeout has occured return data is not to be trusted...
else if (iret != 0)
  MsgBox, Error reported by BFFCOMMS_Get: %iret%
  
  
;Combine the bytes to get word values

if (Timeout_flag = "No")
{
  adc1 := b3 + (b4 * 256)
  adc2 := b5 + (b6 * 256)
  adc3 := b7 + (b8 * 256)
}
else
{
  adc1 := 0
  adc2 := 0
  adc3 := 0
}
  
GuiControl,, Text1, Timeout %Timeout_flag%`n%adc1% : %adc2% : %adc3%`ndata at %F_Loop% Hz

  
; now go back and loop again - ie thread is never ending

}




Finish:  
  
; Close the comport

iret := BFFCOMMS_Close(Handle)
if (iret != 0)
  MsgBox, Error reported by BFFCOMMS_Close: %iret%

; And close this application

ExitApp




;================================================================
;Thread to execute when Close button is clicked....
;================================================================

ButtonClose:
  Goto Finish
Return











